hiproc package
==============

Submodules
----------

hiproc.EDR\_Stats module
------------------------

.. automodule:: hiproc.EDR_Stats
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.FlatFile module
----------------------

.. automodule:: hiproc.FlatFile
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.HiBeautify module
------------------------

.. automodule:: hiproc.HiBeautify
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.HiCal module
-------------------

.. automodule:: hiproc.HiCal
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.HiColorInit module
-------------------------

.. automodule:: hiproc.HiColorInit
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.HiColorNorm module
-------------------------

.. automodule:: hiproc.HiColorNorm
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.HiJACK module
--------------------

.. automodule:: hiproc.HiJACK
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.HiJitReg module
----------------------

.. automodule:: hiproc.HiJitReg
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.HiNoProj module
----------------------

.. automodule:: hiproc.HiNoProj
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.HiPrecisionInit module
-----------------------------

.. automodule:: hiproc.HiPrecisionInit
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.HiSlither module
-----------------------

.. automodule:: hiproc.HiSlither
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.HiStitch module
----------------------

.. automodule:: hiproc.HiStitch
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.HiccdStitch module
-------------------------

.. automodule:: hiproc.HiccdStitch
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.JitPlot module
---------------------

.. automodule:: hiproc.JitPlot
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.SlitherStats module
--------------------------

.. automodule:: hiproc.SlitherStats
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.bfeval module
--------------------

.. automodule:: hiproc.bfeval
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.bitflips module
----------------------

.. automodule:: hiproc.bitflips
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.bitunflip module
-----------------------

.. automodule:: hiproc.bitunflip
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.bobclean module
----------------------

.. automodule:: hiproc.bobclean
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.hiproc module
--------------------

.. automodule:: hiproc.hiproc
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.hirise module
--------------------

.. automodule:: hiproc.hirise
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.img module
-----------------

.. automodule:: hiproc.img
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.lisfix module
--------------------

.. automodule:: hiproc.lisfix
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.mdr2cub module
---------------------

.. automodule:: hiproc.mdr2cub
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.resolve\_jitter module
-----------------------------

.. automodule:: hiproc.resolve_jitter
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.rjdiff module
--------------------

.. automodule:: hiproc.rjdiff
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.rjdiffsmear module
-------------------------

.. automodule:: hiproc.rjdiffsmear
   :members:
   :undoc-members:
   :show-inheritance:

hiproc.util module
------------------

.. automodule:: hiproc.util
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: hiproc
   :members:
   :undoc-members:
   :show-inheritance:
